@@ -5,7 +5,7 @@ use Data::Password::zxcvbn::MatchList;
 use Data::Password::zxcvbn::TimeEstimate qw(estimate_attack_times);
 use Exporter 'import';
 our @EXPORT_OK=qw(password_strength);
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: Dropbox's password estimation logic
 
 
@@ -42,6 +42,7 @@ sub password_strength {
     };
 }
 
+
 1;
 
 __END__
@@ -58,7 +59,7 @@ Data::Password::zxcvbn - Dropbox's password estimation logic
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -80,10 +81,10 @@ pre-built, instead of being partially computed at run time).
 The code has been tested against the L<Python
 port's|https://github.com/dwolfhub/zxcvbn-python>
 F<password_expected_value.json> test. When the dictionaries contain
-exactly the same data (including some words that are loaded wrongly
-due to escaping issues), our results are identical. With the
-dictionaries as provided in this distribution, the results (estimated
-number of guesses) are still within 1%.
+exactly the same data (including some words that are loaded wrongly by
+the Javascript and Python code, due to escaping issues), our results
+are identical. With the dictionaries as provided in this distribution,
+the results (estimated number of guesses) are still within 1%.
 
 =head1 FUNCTIONS
 
@@ -279,8 +280,10 @@ strong passwords
 C<modules>
 
 arrayref of module names to use instead of the built-in
-C<Data::Password::zxcvbn::Match::*>; if you want to I<add> a module,
-you still have to list all the built-ins in this array
+C<Data::Password::zxcvbn::Match::*> classes; if you want to I<add> a
+module, you still have to list all the built-ins in this array; L<<
+C<Data::Password::zxcvbn::Match::BruteForce> >> is special, and if
+included here, it will be ignored
 
 =item *
 
@@ -309,6 +312,20 @@ which regexes to use, see L<< C<Data::Password::zxcvbn::Match::Regex>
 
 =back
 
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<the original implementation by Dropbox|https://github.com/dropbox/zxcvbn>
+
+=item *
+
+L<the Python port|https://github.com/dwolfhub/zxcvbn-python>
+
+=back
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <gianni.ceccarelli@broadbean.com>
