@@ -7,7 +7,7 @@ use overload
     'cmp' => \&compare,
     bool => sub { 1 },
     ;
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: role for match objects
 
 
@@ -92,7 +92,7 @@ Data::Password::zxcvbn::Match - role for match objects
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -231,13 +231,15 @@ passwords. The hash contains:
 
 C<warning>
 
-string, produced by calling L<< /C<feedback_warning> >>
+string (or arrayref for localisation), produced by calling L<<
+/C<feedback_warning> >>
 
 =item *
 
 C<suggestions>
 
-arrayref, produced by calling L<< /C<feedback_suggestions> >>.
+arrayref of strings (or arrayrefs for localisation), produced by
+calling L<< /C<feedback_suggestions> >>.
 
 =back
 
