@@ -4,7 +4,7 @@ with 'Data::Password::zxcvbn::Match';
 use Data::Password::zxcvbn::Combinatorics qw(nCk enumerate_substitution_maps);
 use Data::Password::zxcvbn::RankedDictionaries;
 use List::AllUtils qw(min);
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: match class for words in passwords
 
 
@@ -337,7 +337,7 @@ Data::Password::zxcvbn::Match::Dictionary - match class for words in passwords
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 DESCRIPTION
 
@@ -376,15 +376,7 @@ words extracted from a dump of the English edition of Wikipedia
 
 =item *
 
-C<male_names>
-
-=item *
-
-C<female_names>
-
-=item *
-
-C<surnames>
+C<male_names>, C<female_names>, C<surnames>
 
 common names from the 1990 US census
 
