@@ -2,7 +2,7 @@ package Data::Password::zxcvbn::Match::Regex;
 use Moo;
 with 'Data::Password::zxcvbn::Match';
 use List::AllUtils qw(max);
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: match class for recognisable patterns in passwords
 
 
@@ -118,7 +118,7 @@ Data::Password::zxcvbn::Match::Regex - match class for recognisable patterns in
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 DESCRIPTION
 
@@ -136,7 +136,7 @@ Hashref, the regular expressions that were tried to get this
 match. The values are arrayrefs with 2 elements: the regex itself, and
 the estimated number of guesses per character; for example:
 
-  digits => [ qr{(\p{Nd}+)}, 10 ],
+  digits => [ qr[(\p{Nd}+)], 10 ],
 
 =head2 C<regex_name>
 
