@@ -4,7 +4,7 @@ with 'Data::Password::zxcvbn::Match';
 use Data::Password::zxcvbn::AdjacencyGraph;
 use Data::Password::zxcvbn::Combinatorics qw(nCk);
 use List::AllUtils qw(min);
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: match class for sequences of nearby keys
 
 
@@ -184,7 +184,7 @@ Data::Password::zxcvbn::Match::Spatial - match class for sequences of nearby key
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 DESCRIPTION
 
@@ -230,8 +230,8 @@ token
 
 =head2 C<estimate_guesses>
 
-The number of guesses grows super-linearly with length of the pattern,
-the number of L</turns>, and the amount of L<shifted
+The number of guesses grows super-linearly with the length of the
+pattern, the number of L</turns>, and the amount of L<shifted
 keys|/shifted_count>.
 
 =head2 C<make>
@@ -247,8 +247,10 @@ Scans the C<$password> for substrings that can be produced by typing
 on the keyboards described by the C<graphs>.
 
 The data structure needed for C<graphs> is a bit complicated; look at
-the C<bulid-keyboard-adjacency-graphs> script in the distribution's
-repository.
+the L<< C<build-keyboard-adjacency-graphs> script in the
+distribution's
+repository|https://bitbucket.org/broadbean/p5-data-password-zxcvbn/src/master/maint/build-keyboard-adjacency-graphs
+>>.
 
 =head2 C<feedback_warning>
 
