@@ -1,7 +1,7 @@
 package Data::Password::zxcvbn::Match::UserInput;
 use Moo;
 extends 'Data::Password::zxcvbn::Match::Dictionary';
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: match class for words that match other user-supplied information
 
 
@@ -78,7 +78,7 @@ Data::Password::zxcvbn::Match::UserInput - match class for words that match othe
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 DESCRIPTION
 
@@ -102,7 +102,7 @@ This is a subclass of L<< C<Data::Password::zxcvbn::Match::Dictionary>
     },
   ) };
 
-The <%user_input> hash should be a simple hash mapping field names to
+The C<%user_input> hash should be a simple hash mapping field names to
 strings. It will be converted into a set of dictionaries, one per key,
 containing words extracted from the strings. For example
 
