@@ -6,7 +6,7 @@ use Data::Password::zxcvbn::TimeEstimate qw(guesses_to_score);
 use Module::Runtime qw(use_module);
 use List::AllUtils 0.14 qw(max_by);
 
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: a collection of matches for a password
 
 
@@ -301,7 +301,7 @@ Data::Password::zxcvbn::MatchList - a collection of matches for a password
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -356,7 +356,7 @@ This method extracts, from the L</matches> of the invocant, a list of
 non-overlapping matches with minimum guesses. That list should
 represent the way that a generic password cracker would guess the
 L</password>, and as such is the one that the L<main
-function/Data::Password::zxcvbn/password_strength> will use.
+function|Data::Password::zxcvbn/password_strength> will use.
 
 =head2 C<guesses_log10>
 
