@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Exporter 'import';
 our @EXPORT_OK=qw(estimate_attack_times guesses_to_score display_time);
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: functions to estimate cracking times
 
 
@@ -98,7 +98,7 @@ Data::Password::zxcvbn::TimeEstimate - functions to estimate cracking times
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -221,7 +221,10 @@ scenario. (C<< guesses >= 10e10 >>)
   my ($string,@values) = @{ display_time($time) };
   print My::Localise->get_handle->maketext($string,@values);
 
-Given a C<$time> in seconds, returns a 
+Given a C<$time> in seconds, returns an arrayref suitable for
+L<< C<Locale::Maketext> >>, like:
+
+ [ 'quant,_1,day', 23 ]
 
 =head1 AUTHOR
 
